@@ -1,16 +1,15 @@
 /*
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) version 3.
+ * This program is free software; you can redistribute it and/or modify it
+ * under the terms of the GNU Lesser General Public License as published by
+ * the Free Software Foundation.
  *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
+ * This program is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
+ * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
+ * for more details.
  *
- * You should have received a copy of the GNU Lesser General Public
- * License along with the program; if not, see <http://www.gnu.org/licenses/>
+ * You should have received a copy of the GNU Lesser General Public License
+ * along with this program; if not, see <http://www.gnu.org/licenses/>.
  *
  *
  * Authors:
@@ -23,12 +22,11 @@
 #ifndef __EM_UTILS_H__
 #define __EM_UTILS_H__
 
-#include <sys/types.h>
 #include <gtk/gtk.h>
+#include <sys/types.h>
 #include <camel/camel.h>
 
-#include <libemail-engine/e-mail-session.h>
-#include <libemail-engine/e-mail-utils.h>
+#include <libemail-engine/libemail-engine.h>
 
 #include <mail/e-mail-reader.h>
 #include <mail/em-folder-tree.h>
@@ -36,13 +34,10 @@
 G_BEGIN_DECLS
 
 struct _EMailPartList;
-struct _EShell;
 
 gboolean em_utils_ask_open_many (GtkWindow *parent, gint how_many);
 gboolean em_utils_prompt_user (GtkWindow *parent, const gchar *promptkey, const gchar *tag, ...);
 
-GPtrArray *em_utils_uids_copy (GPtrArray *uids);
-
 void		em_utils_edit_filters		(EMailSession *session,
 						 EAlertSink *alert_sink,
 						 GtkWindow *parent_window);
@@ -63,8 +58,6 @@ void em_utils_selection_get_uidlist (GtkSelectionData *data, EMailSession *sessi
 void em_utils_selection_set_urilist (GtkSelectionData *data, CamelFolder *folder, GPtrArray *uids);
 void em_utils_selection_get_urilist (GtkSelectionData *data, CamelFolder *folder);
 
-EProxy *	em_utils_get_proxy		(void);
-
 /* FIXME: should this have an override charset? */
 gchar *		em_utils_message_to_html	(CamelSession *session,
 						 CamelMimeMessage *msg,
@@ -72,7 +65,7 @@ gchar *		em_utils_message_to_html	(CamelSession *session,
 						 guint32 flags,
 						 struct _EMailPartList *parts_list,
 						 const gchar *append,
-						 guint32 *validity_found);
+						 EMailPartValidityFlags *validity_found);
 
 void		em_utils_empty_trash		(GtkWidget *parent,
 						 EMailSession *session);
@@ -82,9 +75,8 @@ gchar *em_utils_url_unescape_amp (const gchar *url);
 
 void emu_restore_folder_tree_state (EMFolderTree *folder_tree);
 
-gboolean em_utils_is_re_in_subject (struct _EShell *shell,
-				    const gchar *subject,
-				    gint *skip_len);
+gboolean	em_utils_is_re_in_subject	(const gchar *subject,
+						 gint *skip_len);
 
 G_END_DECLS
 
